package com.bonus.canteen.core.account.mapper;

import com.bonus.canteen.core.account.domain.AccCardHis;

import java.util.List;

/**
 * 人员换卡历史记录Mapper接口
 * 
 * @author xsheng
 * @date 2025-04-23
 */
public interface AccCardHisMapper {
    /**
     * 查询人员换卡历史记录
     * 
     * @param id 人员换卡历史记录主键
     * @return 人员换卡历史记录
     */
    public AccCardHis selectAccCardHisById(Long id);

    /**
     * 查询人员换卡历史记录列表
     * 
     * @param accCardHis 人员换卡历史记录
     * @return 人员换卡历史记录集合
     */
    public List<AccCardHis> selectAccCardHisList(AccCardHis accCardHis);

    /**
     * 新增人员换卡历史记录
     * 
     * @param accCardHis 人员换卡历史记录
     * @return 结果
     */
    public int insertAccCardHis(AccCardHis accCardHis);

    /**
     * 修改人员换卡历史记录
     * 
     * @param accCardHis 人员换卡历史记录
     * @return 结果
     */
    public int updateAccCardHis(AccCardHis accCardHis);

    /**
     * 删除人员换卡历史记录
     * 
     * @param id 人员换卡历史记录主键
     * @return 结果
     */
    public int deleteAccCardHisById(Long id);

    /**
     * 批量删除人员换卡历史记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAccCardHisByIds(Long[] ids);
}
